==> ocstore25_4_23.zip: OcStore/Prgm/data/map/CS_peace_town_noodle.lua <==

function E0090()
    MNA()CMU("CS_Anzen")FAI(0)
end
function E0091()
    MNA()CMU("CS_Anzen")FAI(1)
end
function E0092()
    MNA()CMU("CS_Anzen")FAI(2)
end
function E0093()
    MNA()CMU("CS_Anzen")FAI(3)
end
function E0094()
    MNA()CMU("CS_Anzen")FAI(4)
end

function Door_GoPeaceTown()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoPeaceTown",0,1)FAO(2)TRA("CS_peace_town","E0090",69,15)
end

function Igor1()
    if(FLJ("ChatWithIgor")) then
        KEY()
        FAC("jack_normal")MS3("\n我们不需要吃更多面条了。")NOD()
    else
        Igor1_chat()
    end
end

function Igor1_chat()
    KEY()
    MS3("两位好~")NOD()
    CAT("\n要点些面吃嘛？")NOD()CLR()
    CAT("\n杰克，我再不吃点东西就要饿死了...")NOD()CLR()
    FAC("jack_normal")CAT("知道啦，")NOD()
    CAT("\n那就来两碗面条吧~")NOD()CLR()
    FAC()CAT("\n好的请稍等。")NOD()CLO()
    FAO(0)
    MOV(16,14)
    HMC()
    SNP("CS_jack_animate",18,14,0,"mainLayer","Jack1")--杰克
    ANP("Jack1","sit_on_chair")
    ANP("Table1","using")
    SNP("CS_santa_animate",21,14,0,"mainLayer","Santa1")--桑塔
    ANP("Santa1","sit_on_chair")
    ANP("Table2","using")
    FAI(2)
    MS3("\n久等了~")NOD()CLO()
    --伊藤
    SNP("CS_itoh_animate",15,14,1,"mainLayer","Itoh1")--杰克
    ANP("Itoh1","hold_noodle")
    WAI(16)
    ANP("Itoh1","walk",1)
    WAI(16)
    ANP("Itoh1","normal",1)
    WAI(32)
    SOU("CS_023_thud")
    ANP("Table1","noodle")
    WAI(32)
    ANP("Itoh1","walk",1)
    WAI(48)
    ANP("Itoh1","normal",1)
    WAI(32)
    SOU("CS_023_thud")
    ANP("Table2","noodle")
    ANP("Itoh1","empty")
    WAI(32)
    MS3("\n请慢用。")NOD()CLO()
    ANP("Itoh1","walk",0)
    WAI(64)
    ANP("Itoh1","normal",0)
    WAI(16)
    ANP("Itoh1","normal",1)
    WAI(16)
    DNP("Itoh1")
    WAI(32)
    MS3("\n那我开动了！")NOD()CLR()
    FAC("jack_normal")CAT("\n快点吃吧...")NOD()CLO()
    FAO(0)
    ANP("Table1","noodle_eat_up")
    ANP("Table2","noodle_eat_up")
    WAI(64)
    LIP(1000)
    SOU("CS_020_health_refill")
    FAI(2)
    WAI(16)
    FAC("jack_normal")MS3("\n桑塔你吃完了嘛？")NOD()CLR()
    FAC()CAT("\n我早吃完了。")NOD()CLR()
    FAC("jack_normal")CAT("\n那我付完赶紧出发吧。")NOD()CLO()
    ANP("Jack1","normal")
    WAI(16)
    ANP("Jack1","walk",0)
    WAI(16)
    ANP("Santa1","normal")
    WAI(16)
    ANP("Santa1","walk",0)
    WAI(3*16)
    ANP("Jack1","normal",1)
    WAI(32)
    ANP("Jack1","back",1)
    WAI(64)
    ANP("Santa1","normal",1)
    WAI(16)
    MS3("\n欢迎下次再来~")NOD()CLR()
    CAT("对了，我以前没见过你们，")NOD()
    CAT("\n你们是第一次到这个镇子上嘛？")NOD()CLR()
    FAC("jack_normal")CAT("\n嗯，我们今天刚来。")NOD()CLR()
    FAC()CAT("\n你们会说人类语嘛？")NOD()CLR()
    FAC("jack_normal")CAT("\n人类语？")NOD()CLR()
    FAC()CAT("没错，")NOD()
    CAT("\n我们是在这个镇子上")
    CAT("\n少数的咪咪卡营业所之一。")NOD()CLR()
    CAT("要和人类交谈的话，")NOD()
    CAT("\n得说他们的语言。")NOD()CLR()
    CAT("当然我们之间因为都是咪咪卡，")NOD()
    CAT("\n现在直接用咪咪卡语也没问题。")NOD()CLR()
    CAT("但对方是人类的话")
    CAT("\n当然就得用人类语问候了。")NOD()CLR()
    FAC("jack_normal")CAT("原来如此。")NOD()
    FAC("jack_><")CAT("\n但我们不会任何人类语啊。")NOD()CLR()
    FAC()CAT("这个的话，也不是完全没有办法，")NOD()
    CAT("\n用翻译机就行了。")NOD()CLR()
    FAC("jack_normal")CAT("翻译机？")NOD()
    CAT("\n用那个就能和人类交谈了？")NOD()CLR()
    FAC()CAT("没错~")NOD()
    CAT("\n下面一条街上有一家二手电子回收店，")NOD()CLR()
    CAT("虽然是回收物品的，")NOD()
    CAT("\n但实际上也可以")
    CAT("\n便宜的买到一些东西。")NOD()CLR()
    FAC("jack_normal")CAT("\n包括翻译机？")NOD()CLR()
    FAC()CAT("\n没错。")NOD()CLR()
    FAC("jack_normal")CAT("谢谢你和我们讲这么多~")NOD()
    CAT("\n话说你叫...")NOD()CLR()
    FAC()CAT("\n我叫伊格尔。")NOD()CLR()
    FAC("jack_normal")CAT("\n谢谢你，伊格尔。")NOD()CLR()
    FAC()CAT("不客气，")NOD()
    CAT("\n毕竟我们都是咪咪卡嘛~")NOD()CLO()
    FAO(0)
    SMC()
    TRA("CS_peace_town_noodle","Igor1_chat_end",13,14)
end

function Igor1_chat_end()
    KEY()
    MOV(12,14,PLY())
    SLR(1,PLY())
    MOV(13,14,1-PLY())
    SLR(0,1-PLY())
    FAI(2)
    FAC("jack_normal")MS3("\n那么桑塔，我们赶紧出发吧！")NOD()
    FLP("ChatWithIgor")
    MSA("GetTranslator")
end

function Kitchen()
    KEY()
    MS3("\n不需要去厨房..")NOD()
end

--经验胶囊
function NoodleExp1()
    FLP("NoodleExp1")
end
function NoodleExp2()
    FLP("NoodleExp2")
end
function NoodleExp3()
    FLP("NoodleExp3")
end
function NoodleExp4()
    FLP("NoodleExp4")
end

==> ocstore25_12_22.zip: OcStore/Prgm/data/map/CS_peace_town_noodle.lua <==

function E0090()
    MNA()CMU("CS_Anzen")FAI(0)
end
function E0091()
    MNA()CMU("CS_Anzen")FAI(1)
end
function E0092()
    MNA()CMU("CS_Anzen")FAI(2)
end
function E0093()
    MNA()CMU("CS_Anzen")FAI(3)
end
function E0094()
    MNA()CMU("CS_Anzen")FAI(4)
end

function Door_GoPeaceTown()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoPeaceTown",0,1)FAO(2)TRA("CS_peace_town","E0090",69,15)
end

function Igor1()
    if(FLJ("ChatWithIgor")) then
        KEY()
        FAC("jack_normal")MS3("\n我们不需要吃更多面条了。")NOD()
    else
        Igor1_chat()
    end
end

function Igor1_chat()
    KEY()
    MS3("两位好~")NOD()
    CAT("\n要点些面吃嘛？")NOD()CLR()
    CAT("\n杰克，我再不吃点东西就要饿死了...")NOD()CLR()
    FAC("jack_normal")CAT("知道啦，")NOD()
    CAT("\n那就来两碗面条吧~")NOD()CLR()
    FAC()CAT("\n好的请稍等。")NOD()CLO()
    FAO(0)
    MOV(16,14)
    HMC()
    SNP("CS_jack_animate",18,14,0,"mainLayer","Jack1")--杰克
    ANP("Jack1","sit_on_chair")
    ANP("Table1","using")
    SNP("CS_santa_animate",21,14,0,"mainLayer","Santa1")--桑塔
    ANP("Santa1","sit_on_chair")
    ANP("Table2","using")
    FAI(2)
    MS3("\n久等了~")NOD()CLO()
    --伊藤
    SNP("CS_itoh_animate",15,14,1,"mainLayer","Itoh1")
    ANP("Itoh1","hold_noodle")
    WAI(16)
    ANP("Itoh1","walk",1)
    WAI(16)
    ANP("Itoh1","normal",1)
    WAI(32)
    SOU("CS_023_thud")
    ANP("Table1","noodle")
    WAI(32)
    ANP("Itoh1","walk",1)
    WAI(48)
    ANP("Itoh1","normal",1)
    WAI(32)
    SOU("CS_023_thud")
    ANP("Table2","noodle")
    ANP("Itoh1","empty")
    WAI(32)
    MS3("\n请慢用。")NOD()CLO()
    ANP("Itoh1","walk",0)
    WAI(64)
    ANP("Itoh1","normal",0)
    WAI(16)
    ANP("Itoh1","normal",1)
    WAI(16)
    DNP("Itoh1")
    WAI(32)
    MS3("\n那我开动了！")NOD()CLR()
    FAC("jack_normal")CAT("\n快点吃吧...")NOD()CLO()
    FAO(0)
    ANP("Table1","noodle_eat_up")
    ANP("Table2","noodle_eat_up")
    WAI(64)
    LIP(1000)
    SOU("CS_020_health_refill")
    FAI(2)
    WAI(16)
    FAC("jack_normal")MS3("\n桑塔你吃完了嘛？")NOD()CLR()
    FAC()CAT("\n我早吃完了。")NOD()CLR()
    FAC("jack_normal")CAT("\n那我付完赶紧出发吧。")NOD()CLO()
    ANP("Jack1","normal")
    WAI(16)
    ANP("Jack1","walk",0)
    WAI(16)
    ANP("Santa1","normal")
    WAI(16)
    ANP("Santa1","walk",0)
    WAI(3*16)
    ANP("Jack1","normal",1)
    WAI(32)
    ANP("Jack1","back",1)
    WAI(64)
    ANP("Santa1","normal",1)
    WAI(16)
    MS3("\n欢迎下次再来~")NOD()CLR()
    CAT("对了，我以前没见过你们，")NOD()
    CAT("\n你们是第一次到这个镇子上嘛？")NOD()CLR()
    FAC("jack_normal")CAT("\n嗯，我们今天刚来。")NOD()CLR()
    FAC()CAT("\n你们会说人类语嘛？")NOD()CLR()
    FAC("jack_normal")CAT("\n人类语？")NOD()CLR()
    FAC()CAT("没错，")NOD()
    CAT("\n我们是在这个镇子上")
    CAT("\n少数的咪咪卡营业所之一。")NOD()CLR()
    CAT("要和人类交谈的话，")NOD()
    CAT("\n得说他们的语言。")NOD()CLR()
    CAT("当然我们之间因为都是咪咪卡，")NOD()
    CAT("\n现在直接用咪咪卡语也没问题。")NOD()CLR()
    CAT("但对方是人类的话")
    CAT("\n当然就得用人类语问候了。")NOD()CLR()
    FAC("jack_normal")CAT("原来如此。")NOD()
    FAC("jack_><")CAT("\n但我们不会任何人类语啊。")NOD()CLR()
    FAC()CAT("这个的话，也不是完全没有办法，")NOD()
    CAT("\n用翻译机就行了。")NOD()CLR()
    FAC("jack_normal")CAT("翻译机？")NOD()
    CAT("\n用那个就能和人类交谈了？")NOD()CLR()
    FAC()CAT("没错~")NOD()
    CAT("\n下面一条街上有一家二手电子回收店，")NOD()CLR()
    CAT("虽然是回收物品的，")NOD()
    CAT("\n但实际上也可以")
    CAT("\n便宜的买到一些东西。")NOD()CLR()
    FAC("jack_normal")CAT("\n包括翻译机？")NOD()CLR()
    FAC()CAT("\n没错。")NOD()CLR()
    FAC("jack_normal")CAT("谢谢你和我们讲这么多~")NOD()
    CAT("\n话说你叫...")NOD()CLR()
    FAC()CAT("\n我叫伊格尔。")NOD()CLR()
    FAC("jack_normal")CAT("\n谢谢你，伊格尔。")NOD()CLR()
    FAC()CAT("不客气，")NOD()
    CAT("\n毕竟我们都是咪咪卡嘛~")NOD()CLO()
    FAO(0)
    SMC()
    TRA("CS_peace_town_noodle","Igor1_chat_end",13,14)
end

function Igor1_chat_end()
    KEY()
    MOV(12,14,PLY())
    SLR(1,PLY())
    MOV(13,14,1-PLY())
    SLR(0,1-PLY())
    FAI(2)
    FAC("jack_normal")MS3("\n那么桑塔，我们赶紧出发吧！")NOD()
    FLP("ChatWithIgor")
    MSA("GetTranslator")
end

function Kitchen()
    KEY()
    MS3("\n不需要去厨房..")NOD()
end

--经验胶囊
function NoodleExp1()
    FLP("NoodleExp1")
end
function NoodleExp2()
    FLP("NoodleExp2")
end
function NoodleExp3()
    FLP("NoodleExp3")
end
function NoodleExp4()
    FLP("NoodleExp4")
end

function Credit_Cut()
    KEY()
    SNP("CS_mahin_animate",21,14,0,"mainLayer","Mahin1")--马宾
    ANP("Mahin1","sit_on_chair")
    ANP("Table2","using")
    FAI(2)
    WAI(32)
    SNP("CS_itoh_animate",15,14,1,"mainLayer","Itoh1")
    ANP("Itoh1","hold_noodle")
    WAI(16)
    ANP("Itoh1","walk",1)
    WAI(64)
    ANP("Itoh1","normal",1)
    WAI(32)
    SOU("CS_023_thud")
    ANP("Table2","noodle")
    ANP("Itoh1","empty")
    WAI(60)
    FAO(2)
    DNP("Itoh1")
    ANP("Table2","noodle_stacked_eat_up")
    FAI(2)
    WAI(32)
    ANP("Mahin1","normal")
    WAI(32)
    ANP("Mahin1","walk")
    WAI(16*8)
    ANP("Mahin1","normal")
    WAI(32)
    ANP("Mahin1","normal",1)
    WAI(90)
    FAO(2)
    TRA("CS_credit","Credit_Cut6",0,0)
end
